@@ -3,7 +3,7 @@ package kateb;
 use strict;
 use warnings;
 use 5.016;
-our $VERSION = '00.98.12';
+our $VERSION = '00.98.13';
 
 
 1;
@@ -26,11 +26,11 @@ This document describes L<kateb> version B<00.98.12>.
 
 kateb comes with a command-line application which you can use to install and update your fonts.
 
- $ cpanm Mira # Install
+ $ cpanm kateb # Install
 
- $ kateb               # install fonts in ~/.local/share/fonts/farsifreefonts
+ $ kateb       # install fonts in ~/.local/share/fonts/farsifreefonts
 
- $ sudo kateb    # install fonts in /usr/share/fonts/farsifreefonts
+ $ sudo kateb  # install fonts in /usr/share/fonts/farsifreefonts
 
 
 =head1 Author
